/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//******************************************************************************
/*
 * MCx_System.c
 *
 *  Created on: Nov 4, 2019

 */

#include <msp430.h>
#include "driverlib.h"
#include "Defines.h"
#include "Board.h"
#include <MCx_System.h>


void InitSystem(void)
{
    WDT_A_hold(WDT_A_BASE);
    clockValue = CS_getMCLK();

    // Configure Pins for XIN and XOUT
    //Set P2.6 and P2.7 as Module Function Input.
    GPIO_setAsPeripheralModuleFunctionInputPin(
        GPIO_PORT_P2,
        GPIO_PIN6 + GPIO_PIN7,
        GPIO_SECONDARY_MODULE_FUNCTION
    );

    //Initializes the XT1 and XT2 crystal frequencies being used
    CS_setExternalClockSource(
        32768
        );

    //Initialize XT1. Returns STATUS_SUCCESS if initializes successfully
    CS_turnOnXT1LFWithTimeout(CS_XT1_DRIVE_0, 50000);

     CS_initClockSignal(CS_FLLREF, CS_XT1CLK_SELECT, CS_CLOCK_DIVIDER_1);


     //Set ACLK = REFOCLK with clock divider of 1
     CS_initClockSignal(CS_ACLK,CS_XT1CLK_SELECT,CS_CLOCK_DIVIDER_1);

     //Set MCLK = DCO with frequency divider of 1
     CS_initClockSignal(CS_MCLK,SELMS__DCOCLKDIV,CS_CLOCK_DIVIDER_1);

     //Set SMCLK = DCO with frequency divider of 1
     CS_initClockSignal(CS_SMCLK,SELMS__DCOCLKDIV,CS_CLOCK_DIVIDER_1);


     CS_initFLL(16000, 488);          // Clock program to 16MHz
     clockValue = CS_getMCLK();
     clockValue = CS_getSMCLK();

     // Set P1.0 to output direction
    GPIO_setAsOutputPin(
        GPIO_PORT,
        GPIO_PIN
        );

    GPIO_setOutputLowOnPin(
        GPIO_PORT,
        GPIO_PIN
        );


    // Configure Pins for I2C
    GPIO_setAsPeripheralModuleFunctionInputPin(
        GPIO_PORT_UCB1SCL,
        GPIO_PIN_UCB1SCL,
        GPIO_FUNCTION_UCB1SCL
    );
    GPIO_setAsPeripheralModuleFunctionInputPin(
        GPIO_PORT_UCB1SDA,
        GPIO_PIN_UCB1SDA,
        GPIO_FUNCTION_UCB1SDA
    );

    /*
    * Disable the GPIO power-on default high-impedance mode to activate
    * previously configured port settings
    */
    PMM_unlockLPM5();

    EUSCI_B_I2C_initMasterParam param = {0};
    param.selectClockSource = EUSCI_B_I2C_CLOCKSOURCE_SMCLK;
    param.i2cClk = CS_getSMCLK();
    param.dataRate = EUSCI_B_I2C_SET_DATA_RATE_400KBPS;
    param.byteCounterThreshold = 4;
    param.autoSTOPGeneration = EUSCI_B_I2C_SEND_STOP_AUTOMATICALLY_ON_BYTECOUNT_THRESHOLD;
    EUSCI_B_I2C_initMaster(EUSCI_I2C_BASE, &param);



    //Set Master in receive mode
    EUSCI_B_I2C_setMode(EUSCI_I2C_BASE,
        EUSCI_B_I2C_TRANSMIT_MODE
    );

    //Enable I2C Module to start operations
    EUSCI_B_I2C_enable(EUSCI_I2C_BASE);

}

